@@ -11,6 +11,11 @@ from labml.internal.analytics.altair import histogram as _histogram
 from labml.internal.analytics.altair import scatter as _scatter
 from labml.internal.analytics.altair import binned_heatmap as _binned_heatmap
 from labml.internal.analytics.indicators import IndicatorCollection as _IndicatorCollection
+from labml.internal.analytics.models import ModelProbe as _ModelProbe
+from labml.internal.analytics.models import ValueCollection as _ValueCollection
+from labml.internal.analytics.models import DeepValueCollection as _DeepValueCollection
+from labml.internal.analytics.viz import text_attention as _text_attention
+from labml.internal.analytics.viz import init_inline_viz as _init_inline_viz
 
 
 def _remove_names_prefix(names: List[Union[str, List[str]]]) -> List[str]:
@@ -65,6 +70,38 @@ class IndicatorCollection(_IndicatorCollection):
     pass
 
 
+class ModelProbe(_ModelProbe):
+    r"""
+    You can wrap any PyTorch model with :class:`ModelProbe` to access it's parameters, activations and gradients.
+
+    `Here's a notebook with example usage <https://github.com/labmlai/labml/blob/master/guides/model_probe.ipynb>`_
+
+    >>> from labml.analytics import ModelProbe
+    >>> probe = ModelProbe(model)
+    >>> outputs = model(inputs)
+    >>> outputs.backward()
+    >>> probe.forward_output["*attention*"].get_dict()
+    >>> probe.parameters['*.bias'].get_list()
+    """
+    pass
+
+
+class ValueCollection(_ValueCollection):
+    pass
+
+
+class DeepValueCollection(_DeepValueCollection):
+    pass
+
+
+def text_attention(attn: 'torch.Tensor', src_tokens: List[str], tgt_tokens: List[str]):
+    _text_attention(attn, src_tokens, tgt_tokens)
+
+
+def init_inline_viz():
+    _init_inline_viz()
+
+
 def runs(*uuids: str):
     r"""
     This is used to analyze runs.
@@ -87,6 +124,10 @@ def runs(*uuids: str):
     return indicators
 
 
+def get_experiment_runs(experiment_name: str):
+    return _cache.get_experiment_runs(experiment_name)
+
+
 def get_run(uuid: str):
     r"""
     Returns ``Run`` object
@@ -110,6 +151,7 @@ def set_preferred_db(db: str):
 def distribution(indicators: IndicatorCollection, *,
                  names: Optional[List[str]] = None,
                  levels: int = 5, alpha: int = 0.6,
+                 color_scheme: str = 'tableau10',
                  height: int = 400, width: int = 800, height_minimap: int = 100):
     ...
 
@@ -118,6 +160,7 @@ def distribution(indicators: IndicatorCollection, *,
 def distribution(series: List[Union[np.ndarray, 'torch.Tensor']], *,
                  names: Optional[List[str]] = None,
                  levels: int = 5, alpha: int = 0.6,
+                 color_scheme: str = 'tableau10',
                  height: int = 400, width: int = 800, height_minimap: int = 100):
     ...
 
@@ -127,6 +170,7 @@ def distribution(series: List[Union[np.ndarray, 'torch.Tensor']],
                  step: np.ndarray, *,
                  names: Optional[List[str]] = None,
                  levels: int = 5, alpha: int = 0.6,
+                 color_scheme: str = 'tableau10',
                  height: int = 400, width: int = 800, height_minimap: int = 100):
     ...
 
@@ -135,6 +179,7 @@ def distribution(series: List[Union[np.ndarray, 'torch.Tensor']],
 def distribution(series: Union[np.ndarray, 'torch.Tensor'], *,
                  names: Optional[List[str]] = None,
                  levels: int = 5, alpha: int = 0.6,
+                 color_scheme: str = 'tableau10',
                  height: int = 400, width: int = 800, height_minimap: int = 100):
     ...
 
@@ -142,6 +187,7 @@ def distribution(series: Union[np.ndarray, 'torch.Tensor'], *,
 def distribution(*args: any,
                  names: Optional[List[str]] = None,
                  levels: int = 5, alpha: int = 0.6,
+                 color_scheme: str = 'tableau10',
                  height: int = 400, width: int = 800, height_minimap: int = 100):
     r"""
     Creates a distribution plot distribution with Altair
@@ -169,6 +215,7 @@ def distribution(*args: any,
         names(List[str]): List of names of series
         levels: how many levels of the distribution to be plotted
         alpha: opacity of the distribution
+        color_scheme: color scheme
         height: height of the visualization
         width: width of the visualization
         height_minimap: height of the view finder
@@ -215,6 +262,7 @@ def distribution(*args: any,
         tables,
         levels=levels,
         alpha=alpha,
+        color_scheme=color_scheme,
         width=width,
         height=height,
         height_minimap=height_minimap)
