@@ -1,14 +1,16 @@
 import argparse
+import os
 import subprocess
+import sys
 import threading
 import time
-import webbrowser
 from typing import List
 
 from labml import logger, experiment
 from labml.experiment import generate_uuid
 from labml.internal.api import ApiCaller, SimpleApiDataSource
 from labml.internal.api.logs import ApiLogs
+from labml.internal.api.url import ApiUrlHandler
 from labml.logger import Text
 from typing.io import IO
 
@@ -47,12 +49,18 @@ class ExecutorThread(threading.Thread):
         self.exit_code = 0
 
     def _read(self, stream: IO, name: str):
+        buffer = ''
         while stream.readable():
-            data = stream.read(1024).decode('utf-8')
+            data = stream.read(1)
             if len(data) == 0:
                 break
-            print(data)
-            self.api_logs.outputs(**{name: data})
+            buffer += data
+            print(data, end='')
+            if '\n' in buffer or len(buffer) > 100:
+                self.api_logs.outputs(**{name: buffer})
+                buffer = ''
+        if len(buffer) > 0:
+            self.api_logs.outputs(**{name: buffer})
 
     def _read_stdout(self):
         self._read(self.process.stdout, 'stdout_')
@@ -61,7 +69,19 @@ class ExecutorThread(threading.Thread):
         self._read(self.process.stderr, 'stderr_')
 
     def run(self):
-        self.process = subprocess.Popen(self.command, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        shell = os.environ.get('SHELL', '/bin/sh')
+
+        self.process = subprocess.Popen(
+            self.command,
+            # [shell, '-i', '-c', self.command],
+            encoding='utf-8',
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            shell=True,
+            env=os.environ.copy(),
+            executable=shell,
+            bufsize=0,
+        )
 
         while True:
             self._read_stdout()
@@ -85,19 +105,30 @@ def _capture(args: List[str]):
         'time': time.time()
     }
 
-    def _started(url):
-        if url is None:
-            return None
-
-        logger.log([('Monitor experiment at ', Text.meta), (url, Text.link)])
-        webbrowser.open(url)
-
-    api_caller.has_data(SimpleApiDataSource(data, callback=_started))
+    api_caller.add_handler(ApiUrlHandler(True, 'Monitor output at '))
+    api_caller.has_data(SimpleApiDataSource(data))
     api_logs.set_api(api_caller, frequency=0)
 
-    thread = ExecutorThread(' '.join(args), api_logs)
-    thread.start()
-    thread.join()
+    logger.log('Start capturing...', Text.meta)
+    if args:
+        thread = ExecutorThread(' '.join(args), api_logs)
+        thread.start()
+        thread.join()
+    else:
+        buffer = ''
+        stdin = sys.stdin
+        while stdin.readable():
+            data = stdin.read(1)
+            if len(data) == 0:
+                break
+            print(data, end='')
+            buffer += data
+            if '\n' in buffer or len(buffer) > 100:
+                api_logs.outputs(stdout_=buffer)
+                buffer = ''
+        if len(buffer) > 0:
+            api_logs.outputs(stdout_=buffer)
+
     data = {
         'rank': 0,
         'status': 'completed',
@@ -196,3 +227,11 @@ def main():
         _service_run()
     else:
         raise ValueError('Unknown command', args.command)
+
+
+def _test_capture():
+    _capture([])
+
+
+if __name__ == '__main__':
+    _test_capture()
