@@ -17,6 +17,8 @@ from labml.internal.monitor import monitor_singleton as monitor
 if TYPE_CHECKING:
     import torch
 
+AVAILABLE_WRITERS = {'screen', 'web_api', 'sqlite', 'tensorboard', 'wandb', 'comet', 'file'}
+
 
 def generate_uuid() -> str:
     from uuid import uuid1
@@ -67,11 +69,14 @@ def create(*,
         from labml.internal.util.tensorboard_writer import has_tensorboard
         if has_tensorboard():
             writers.add('tensorboard')
-        try:
-            import wandb
-            writers.add('wandb')
-        except ImportError:
-            pass
+
+    if 'labml' in writers:
+        writers.remove('labml')
+        writers.add('web_api')
+
+    for w in writers:
+        if w not in AVAILABLE_WRITERS:
+            raise ValueError(f'Unknown writer: {w}')
 
     if disable_screen and 'screen' in writers:
         writers.remove('screen')
@@ -83,6 +88,7 @@ def create(*,
         uuid = generate_uuid()
 
     monitor().clear()
+
     _create_experiment(uuid=uuid,
                        name=name,
                        python_file=python_file,
