@@ -55,14 +55,13 @@ class Tracker:
     def add_writer(self, writer: Writer):
         self.__writers.append(writer)
 
+    def remove_writer(self, writer: Writer):
+        self.__writers.remove(writer)
+
     def reset_writers(self):
         self.__writers = []
         self.is_indicators_updated = True
 
-    def write_h_parameters(self, hparams: Dict[str, any]):
-        for w in self.__writers:
-            w.write_h_parameters(hparams)
-
     def _write_writer(self, writer: Writer, global_step):
         return writer.write(global_step=global_step,
                             indicators=self.indicators)
