@@ -53,8 +53,9 @@ class Writer(WriteBase, ApiDataSource):
     def write(self, *,
               global_step: int,
               indicators: Dict[str, Indicator]):
-        for ind in indicators.values():
-            self._write_indicator(global_step, ind)
+        with self.lock:
+            for ind in indicators.values():
+                self._write_indicator(global_step, ind)
 
         t = time.time()
         freq = self.frequency
@@ -80,6 +81,19 @@ class Writer(WriteBase, ApiDataSource):
 
         self.api_caller.has_data(self)
 
+    def _mean(self, values: np.ndarray, n_elems: int):
+        blocks = (len(values) + n_elems - 1) // n_elems
+        if len(values) % n_elems != 0:
+            n_elems = len(values) // blocks
+        means = []
+        if blocks > 0:
+            means.append(np.mean(values[:blocks * n_elems].reshape(n_elems, blocks), axis=-1))
+
+        if len(values) > blocks * n_elems:
+            means.append(np.mean(values[blocks * n_elems:].reshape(1, -1), axis=-1))
+
+        return np.concatenate(means)
+
     def get_and_clear_indicators(self):
         data = {}
 
@@ -90,14 +104,14 @@ class Writer(WriteBase, ApiDataSource):
             value = np.array(value)
             step: np.ndarray = value[:, 0]
             value: np.ndarray = value[:, 1]
-            while value.shape[0] > MAX_BUFFER_SIZE:
-                if value.shape[0] % 2 == 1:
-                    value = np.concatenate((value, value[-1:]))
-                    step = np.concatenate((step, step[-1:]))
-
-                n = value.shape[0] // 2
-                step = np.mean(step.reshape(n, 2), axis=-1)
-                value = np.mean(value.reshape(n, 2), axis=-1)
+            n = len(step)
+            if n > 1:
+                diff = (step[-1] - step[0] + 1) * n / (n - 1)
+                start_step = max(step[0], 1)
+                max_buffer_size = max(1, int(min(MAX_BUFFER_SIZE, 1000 / start_step * diff)))
+                if len(value) > max_buffer_size:
+                    step = self._mean(step, max_buffer_size)
+                    value = self._mean(value, max_buffer_size)
 
             data[key] = {
                 'step': step.tolist(),
